@@ -1,4 +1,4 @@
-gmrae = function(forecast, forecastbench, true)
+gmrae <- function(forecast, forecastbench, true)
 {
   if (length(forecast) != length(true))
       stop("GMRAE: the lengths of input vectors must be the same.")
