@@ -1,4 +1,4 @@
-`rmse` <- function(forecast, true)
+rmse <- function(forecast, true)
 {
     if (length(forecast) != length(true))
         stop("RMSE: the lengths of input vectors must be the same.")
